@@ -79,6 +79,9 @@ def _normalize_vendor(vendor):
     return vendor
 
 
+def _convert_items_to_metis_tags(tags_dict: Optional[Attributes]):
+    return {f'app.tag.{key}': val for key, val in tags_dict.items()}
+
 def _build_resource(
         service_name: str,
         service_version: str,
@@ -97,11 +100,12 @@ def _build_resource(
         logger.exception("Cloudnt get hostname for service")
 
     if resource_tags:
-        attrs.update(resource_tags)
+        attrs.update(_convert_items_to_metis_tags(resource_tags))
 
     metis_tags_env_vars = extract_additional_tags_from_env_var()
     if len(metis_tags_env_vars) > 0:
-        attrs.update({'app.tag.' + key: val for key, val in metis_tags_env_vars.items()})
+        attrs.update(_convert_items_to_metis_tags(metis_tags_env_vars))
+
 
     return Resource.create(attrs)
 
